package com.jz.dmp.modules.controller.DataIntegration;

import com.jz.common.constant.JsonResult;
import com.jz.common.constant.ResultCode;
import com.jz.common.page.PageInfoResponse;
import com.jz.common.utils.realTime.CmdUtils;
import com.jz.dmp.modules.controller.DataIntegration.bean.RealTimeSyncListDto;
import com.jz.dmp.modules.controller.DataIntegration.bean.RealTimeSyncListReq;
import com.jz.dmp.modules.model.DmpRealtimeSyncInfo;
import com.jz.dmp.modules.service.DmpRealtimeSyncInfoService;
import com.jz.dmp.modules.service.impl.OfflineSynchServiceImpl;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;

/**
 * 实时同步任务
 *
 * @author Bellamy
 * @since 2021-01-05 10:56:18
 */
@RestController
@RequestMapping("/realTimeSync")
@Api(tags = "数据集成--实时同步任务")
public class RealTimeSyncController {

    private static Logger logger = LoggerFactory.getLogger(RealTimeSyncController.class);
    /**
     * 服务对象
     */
    @Autowired
    private DmpRealtimeSyncInfoService dmpRealtimeSyncInfoService;

    /**
     * 实时同步任务列表分页查询
     *
     * @return
     * @author Bellamy
     * @since 2021-01-05
     */
    @ApiOperation(value = "实时同步任务列表分页查询", notes = "实时同步任务列表分页查询")
    @PostMapping(value = "/realTimeSyncListPage")
    public PageInfoResponse<RealTimeSyncListDto> getDataSourceListPage(@RequestBody RealTimeSyncListReq req, HttpServletRequest httpRequest) throws Exception {
        PageInfoResponse<RealTimeSyncListDto> pageInfo = new PageInfoResponse<RealTimeSyncListDto>();
        if (StringUtils.isEmpty(req.getProjectId())) {
            pageInfo.setMessage("项目id不能为空！");
            pageInfo.setCode(ResultCode.PARAMS_ERROR);
            return pageInfo;
        }
        try {
            pageInfo = dmpRealtimeSyncInfoService.queryRealTimeSyncListPage(req);
        } catch (Exception e) {
            pageInfo.setMessage("查询失败");
            pageInfo.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            e.printStackTrace();
        }
        return pageInfo;
    }

    /**
     * 启动实时同步任务
     *
     * @return
     * @author Bellamy
     * @since 2021-01-05
     */
    @ApiOperation(value = "启动实时同步任务", notes = "启动实时同步任务")
    @GetMapping(value = "/startRealTimeSync")
    @ApiImplicitParam(name = "realTaskId", value = "任务id")
    public JsonResult startRealTimeSync(@RequestParam String realTaskId) throws Exception {
        if (StringUtils.isEmpty(realTaskId)) {
            return new JsonResult(ResultCode.PARAMS_ERROR, "任务id不能为空！");
        }
        DmpRealtimeSyncInfo dmpRealtimeSyncInfo = dmpRealtimeSyncInfoService.queryById(Integer.valueOf(realTaskId));
        String srcTopicName = dmpRealtimeSyncInfo.getSrcTopicName();
        System.out.println(srcTopicName);
        logger.info("############正常执行表数据........"+realTaskId);
        String shellPath ="/app/bigdata-app/scripts/trigger_straming.sh";
        CmdUtils.callShell(shellPath, srcTopicName);
        return new JsonResult();
    }

}